@@ -18,10 +18,12 @@ class Dynamo:
                                  region_name=c['region'])
         # Retrieve DynamoDB table resource
         dynamo_table = dynamodb.Table(c['cdc_dynamo_table'])
-        return dynamo_table.scan(FilterExpression=Attr(c['cdc_customer_id_attr']).eq(customer_id))['Items'][0]
+        items = dynamo_table.scan(FilterExpression=Attr(c['cdc_customer_id_attr']).eq(customer_id))['Items']
+        return items[0] if len(items) > 0 else None
 
     def get_cdc_features(self, customer_id):
         c = self.connections[cdc_connection]
         item = self.get_cdc_data(customer_id)
 
-        return {'data': item, 'features': CDCParser(item[c['cdc_json_attr']]).get_features()}
+        return {'data': item, 'features': CDCParser(item[c['cdc_json_attr']]).get_features()} \
+            if item is not None and c['cdc_json_attr'] in item else None
