@@ -1,5 +1,6 @@
 from .util import get_data_yaml_dict
 from sqlalchemy import create_engine
+from sqlalchemy.engine.url import URL
 import pandas as pd
 
 
@@ -10,7 +11,14 @@ class MYSQL:
     def get_query_results(self, query, connection, database=None):
         c = self.connections[connection]
         database = c['database'] if 'database' in c else database
-        db_connection_str = f'mysql+pymysql://{c["username"]}:{c["password"]}@{c["host"]}:{c["port"]}/{database}'
-        db_connection = create_engine(db_connection_str)
+        db_url = {
+            'drivername': 'mysql+pymysql',
+            'username': c['username'],
+            'password': c['password'],
+            'host': c['host'],
+            'database': database,
+            'query': {'charset': 'UTF8MB4'},
+        }
+        db_connection = create_engine(URL(**db_url))
         return pd.read_sql(query, con=db_connection)
 
